@@ -1,7 +1,7 @@
 package Sah::SchemaR::rinci::function_meta;
 
-our $DATE = '2016-12-10'; # DATE
-our $VERSION = '1.1.82.1'; # VERSION
+our $DATE = '2016-12-26'; # DATE
+our $VERSION = '1.1.82.2'; # VERSION
 
 our $rschema = do {
   my $a = [
@@ -180,13 +180,13 @@ Sah::SchemaR::rinci::function_meta - Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 1.1.82.1 of Sah::SchemaR::rinci::function_meta (from Perl distribution Sah-Schemas-Rinci), released on 2016-12-10.
+This document describes version 1.1.82.2 of Sah::SchemaR::rinci::function_meta (from Perl distribution Sah-Schemas-Rinci), released on 2016-12-26.
 
 =head1 DESCRIPTION
 
 This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.
 
-A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema wihout having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.
+A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.
 
 =head1 HOMEPAGE
 
